@@ -12,7 +12,7 @@ use Data::Dumper;
 use Net::Google::Blogger::Blog;
 
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 has login_id   => ( is => 'ro', isa => 'Str', required => 1 );
 has password   => ( is => 'ro', isa => 'Str', required => 1 );
@@ -108,11 +108,11 @@ __END__
 
 =head1 NAME
 
-Net::Google::Blogger - Interface to Google's Blogger service
+Net::Google::Blogger - (** DEPRECATED **) Interface to Google's Blogger service.
 
 =head1 VERSION
 
-Version 0.08
+Version 0.09
 
 =cut
 
@@ -120,6 +120,8 @@ Version 0.08
 
 =head1 SYNOPSIS
 
+This module is deprecated. Please use L<WebService::Blogger>.
+
 This module suite provides interface to the Blogger service now run by
 Google. It's built in object-oriented fashion using Moose, which makes
 it easy to use and extend. It also utilizes newer style GData API for
